@@ -8,7 +8,6 @@ import (
 	"bufio"
 	"bytes"
 	"fmt"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"os/signal"
@@ -194,6 +193,7 @@ func main() {
 	// Last resort, print all matches.
 	v.commandPrintMatches([]int{})
 	v.waiter.Wait()
+	os.Exit(0)
 }
 
 // runCommand executes the program specified in args and returns the stdout as
@@ -241,6 +241,10 @@ func (v *vgrep) insideGitTree() bool {
 	return inside
 }
 
+func (v *vgrep) isOpenBSD() bool {
+	return runtime.GOOS == "openbsd"
+}
+
 // ripgrepInstalled returns true if ripgrep is installed
 func (v *vgrep) ripgrepInstalled() bool {
 	out, err := exec.LookPath("rg")
@@ -310,6 +314,11 @@ func (v *vgrep) grep(args []string) {
 		}
 		cmd = append(cmd, args...)
 		greptype = GITGrep
+	} else if v.isOpenBSD() && v.getGrepType() == "" {
+		// grep --version = "grep version 0.9"
+		cmd = []string{"grep", "-ZHInr"}
+		cmd = append(cmd, args...)
+		greptype = BSDGrep
 	} else {
 		env = "GREP_COLORS='ms=01;31:mc=:sl=:cx=:fn=:ln=:se=:bn='"
 		cmd = []string{"grep", "-ZHInr", "--color=always"}
@@ -575,7 +584,7 @@ func (v *vgrep) loadCache() error {
 		}
 	}()
 
-	file, err := ioutil.ReadFile(cache)
+	file, err := os.ReadFile(cache)
 	if err != nil {
 		return err
 	}
@@ -632,7 +641,7 @@ func shellCompleter(line string) (c []string) {
 			dir = arg
 			base = ""
 		}
-		files, err := ioutil.ReadDir(dir)
+		files, err := os.ReadDir(dir)
 		if err != nil {
 			return
 		}
